<?php
/**
* Base class of all analyser
* @author	 Ulf Wendel <ulf@redsys.de>
* @version 0.2alpha
* @since 	 0.2alpha
*/
class PhpdocAnalyserObject extends PhpdocObject {

	/**
	* Array of classes returned by the parser
	* @var	array	$classes
	* @see	setClasses()
	*/
	var $classes = array();
	
	/**
	* Mapping from classnames to filenames returned by the parser
	* @var	array	$classnamesToFilenames
	* @see	setClassnamesToFilenames()
	*/
	var $classnamesToFilenames = array();
	
	/**
	* @var	array	$classTree
	* @see	buildClasstree()
	*/
	var $classTree = array();
	
	/**
	* Initializes the analyser with the class data
	* @param	array	$classes
	* @return	bool	$ok
	* @throws	runtime_wrongparam	
	* @see		classes
	* @access	public
	*/
	function setClasses($classes) {
		if (!is_array($classes)) {
			$this->err = new exception_runtime_wrongparam("No classdata given.", 1, __FILE__, __LINE__, $this->AUTO_HANDLE_ERRORS);
			return false;
		}
		
		$this->classes = $classes;
		return true;
	} // end func setClasses
	
	/**
	* Initializes the analyser with the classname to filename mapping array
	* @param	array	$classnamesToFilenames
	* @return	bool	$ok
	* @throws	runtime_wrongparam
	* @see		classnamesToFilenames
	* @access	public
	*/
	function setClassnamesToFilenames($classnamesToFilenames) {
		if (!is_array($classnamesToFilenames)) {
			$this->err = new exception_runtime_wrongparam("No classname to filename mapping array given.", 2, __FILE__, __LINE__, $this->AUTO_HANDLE_ERRORS);
			return false;
		}
		
		$this->classnamesToFilenames = $classnamesToFilenames;
		return true;
	} // end func setClassnamesToFilenames
	
	/**
	* Start the analyser
	* @abstract
	*/
	function analyse() {
		die();
	} // end func analyse
	
} // end class PhpdocAnalyserObject
?>