<?php
/**
* Handling of exceptions. This class is derived from exception.
* It provides methods to handle all of the five basic exceptions:
* notice, warning, error, io, runtime. 
* @author		Ulf Wendel <ulf@redsys.de>
* @version	0.1
*/
class exception_handler extends exception {

	/**
	* Default reaction on certain exceptions. 
	* @var		array	$action
	* @access	private
	* @see		handle(), show(), halt()
	*/	
	var $action = array(
												"notice"	=> array ("show"	=> true, "halt"	=> false),
												"warning"	=> array ("show"	=> true, "halt"	=> false),
												"error"		=> array ("show"	=> true, "halt"	=> true),
												"io"			=> array ("show"	=> true, "halt"	=> true),
												"runtime"	=> array ("show"	=> true, "halt"	=> false)
										);

	/**
	* Handles an exception. Shows it and halts the script depending in the action flags.
	* @access	public
	* @see		show(), halt()
	*/
	function handle() {
		if (!is_array($this->action[$this->type]))
			return;
			
		if (true == $this->action[$this->type]["show"])
			$this->show();
			
		if (true == $this->action[$this->type]["halt"])
			die();
			
	} // end func handle
	
	/**
	* Shows/prints the exception, no matter what's the default action.
	* @access	public
	* @see		handle(), halt()
	*/
	function show() {
		printf("<b>[%s Exception]</b>: (%d) %s <b>in %s on line %d</b><br>",
							ucfirst($this->type),
							$this->errno,
							$this->message,
							$this->file,
							$this->line
						);
	} // end func show
	
	/**
	* Print the exception and halts the script, no matter what's the 
	* default action.
	* @access	public
	* @see		handle(), show()
	*/
	function halt() {
		$this->show();
		die();	
	} // end func halt
	
} // end func exception_handler
?>