<?php
/**
* Takes the analysing result an copies the data to new arrays that help generation overviews
* @author		Ulf Wendel	<ulf@redsys.de>
* @version	0.1alpha
*/
class PhpdocIndexerObject extends PhpdocObject {

	/**
	* Array of packages
	* @var	array	$packages
	* @see	setPackages()
	*/
	var $packages = array();
	
	/**
	* Name of the current application
	* @var	string	$application
	* @see	setApplication()
	*/
	var $application = "";

	/**
	* Result of the indexer
	* @var	array	$result
	* @see	getResult()
	*/	
	var $result = array();		
	
	var $emptyClassTree = array(
																"baseclasses"		=> array(),
																"subclasslist"	=> array(),
																"classinfo"			=> array()
														);
	/**
	* Initalize the object.
	* @param	string	$application
	* @param	array		$packages
	* @param	bool		$flagOutput
	* @access	public
	* @see	setFlagOutput(), setPackages()
	*/
	function PhpdocIndexerObject($application, $packages, $flagOutput = false) {
	
		$this->setApplicationname($application);
		$this->setPackages($packages);
		$this->setFlagOutput($flagOutput);
		
	} // end constructor
	
	/**
	* Sets the name of the current application
	* @param	string	$application
	* @return	boolean	$ok
	* @throws	runtime_wrongparam
	* @access	public
	* @see		application, PhpdocIndexerObject()
	*/
	function setApplicationname($application) {
		if (""==$application) {
			$this->err = new exception_runtime_wrongparam("No applicationname given.", 2, __FILE__, __LINE__, $this->AUTO_HANDLE_ERRORS);
			return false;
		}	
		
		$this->application = $application;
		return true;
	} // end func setApplicationname
	
	/**
	* Sets the package array
	* @param	array	$packages
	* @return	bool	$ok
	* @throws	runtime_wrongparam
	* @access	public
	* @see		packages, PhpdocIndexerObject()
	*/
	function setPackages($packages) {
		if (!is_array($packages)) {
			$this->err = new exception_runtime_wrongparam("No packages given.", 1, __FILE__, __LINE__, $this->AUTO_HANDLE_ERRORS);
			return false;
		}
		
		$this->packages = $packages;
		return true;
	} // end func setPackages
	
	/**
	* Array with the result of the indexer
	* @var	array	$result
	* @see	getResult()
	*/
	function getResult() {
		return $this->result;
	} // end func getResult
	
} // end class PhpdocIndexerObject
?>