<?php
/**
* "Main" class of the Parser collection.
* 
*/
class PhpdocParser extends PhpdocClassParser {
			
	/**
	* Array of PHP Sourcecode Files to examine.
	* The array keys hold the filenames, the array values the file content.
	* @var	array		$phpfiles
	* @see	parse()
	*/													
	var	$phpfiles = array();													
	
	/**
	* Array with the parsing result
	* @var	array	$result
	*/
	var $result = array();

	/**	
	* Array of Parser warnings
	* @var	array	$warnings
	*/
	var $warnings = array();
	
	/**
	* Mapping from classnames to filenames
	* @var	array	$classnamesToFilenames
	*/
	var $classnamesToFilenames = array();
		
	/**
	* Just calls Setup() to setup some RegExp...
	* @see	Setup()
	*/
	function PhpdocParser($flag_output) {
	
		if ($flag_output)
			$this->setFlagOutput(true);
		else 
			$this->setFlagOutput(true);
			
		$this->Setup();
	} // end constructor
	
	/**
	* Runs the parsing process and returns the resulting array.
	* @return	array $result
	* @access	public
	* @see		getClassnamesToFilenames()
	*/
	function parse() {
	
		if (0==count($this->phpfiles))
			return false;
		
		reset($this->phpfiles);
		while (list($filename, $phpcode)=each($this->phpfiles)) {

			$paragraphs = $this->getPhpdocParagraphs($phpcode, "classes");
			$this->result[$filename] = $this->analyseClasses($paragraphs["classes"]);
			
			$classcode = $this->getClasscode($phpcode);

			reset($classcode);
			while (list($classname, $code)=each($classcode)) {
			
				$this->outl("   ... parsing class '$classname'");
				
				if (isset($this->classnamesToFilenames[$classname])) {
					// phpdoc can't handle applications where classnames are not unique
					$this->warnings["skipped"][] = sprintf("Class '%s' exists in file '%s' and '%s'. Can't handle this, classnames must be unique, class ignored!",
																				$classname,
																				$filename,
																				$this->classnamesToFilenames[$classname]
																			);
					
					$this->outl("   ... error: classnames must be unique - skipping '$filename'/'$classname'");
																						
					if (isset($this->result[$filename][$classname]))
						unset($this->result[$filename][$classname]);
						
					continue;
				}
				
				$this->classnamesToFilenames[$classname] = $filename;
				// undocumented classes!
				if (!isset($this->result[$filename][$classname])) {
				
					if (!preg_match($this->PHP_CLASS, $code, $regs)) 
						preg_match($this->PHP_CLASS_EXTEND, $code, $regs);
				
					list($classname, $extends) = $this->getClassnamesFromRegs($regs);
					$this->result[$filename][$classname] = $this->emptyClass;
					$this->result[$filename][$classname]["classname"] 	= $classname;
					$this->result[$filename][$classname]["extends"]			= $extends;
					$this->result[$filename][$classname]["undocumented"]= true;									
					
				}
				
				$this->result[$filename][$classname]["functions"] = $this->analyseFunctions($code);
				$this->result[$filename][$classname]["variables"] = $this->analyseVariables($code);
				
			} // end while classcode
			
		} // end while phpfiles
				
		return $this->result;
	} // end func parse
	
	/**
	* Returns the mapping array from classnames to filenames
	* @return array	$classnamesToFilenames
	* @see	classnamesToFilenames
	*/
	function getClassnamesToFilenames() {
		return $this->classnamesToFilenames;
	} // end func getClassnamesToFilenames

	
	/**
	* Sets the list of PHP Soucecode Files to examine.
	* @param	array		$phpfiles
	* @return	bool		$ok
	* @access	public
	*/
	function setPhpSourcecodeFiles($phpfiles) {
		if (!is_array($phpfiles) || 0==count($phpfiles)) 
			return false;
		
		$this->phpfiles = $phpfiles;
		return true;	
	} // end func setPhpSourcecodeFiles
	
	/**
	* Returns the warnings from the parser
	* @return array	$warnings
	* @access	public
	*/
	function getWarnings() {
		return $this->warnings;
	} // end func getWarnings
	
} // end class PhpdocParser
?>