<?php
/**
* Function Renderer in Phpdoc.
* @author	Ulf Wendel <ulf@redsys.de>
* @version 0.1
*/
class PhpdocFunctionRenderer extends PhpdocRendererObject {

	/**
	* Renders one function in detail view.
	* @param	string	$functionname
	* @param	array		$data
	* @return	string	$html
	* @throws	runtime_wrongparam
	* @access	public
	*/
	function getFunctionDetail($functionname, $data) {
		if (""==$functionname || !is_array($data)) {
			$this->error = new exception_runtime_wrongparam("No functionname and/or no functiondata given.", 1, __FILE__, __LINE__, $this->AUTO_HANDLE_ERRORS);
			return "";
		}

		$see		= $this->getSee($data["see"]);
		$len 		= strlen($functionname) + strlen($data["return"]["type"]) + strlen($data["access"]) + 2;
		$param_overview = $this->getParamOverview($functionname, $data["param"], $len);
			
		if ("string"!=gettype($data["abstract"]) && true==$data["abstract"] )
			$abstract = " abstract ";
		else
			$abstract = "";
		
		if ("string"!=gettype($data["static"]) && true == $data["static"] )
			$static = " static ";
		else
			$static = "";

		
		$html = sprintf('<a name="%s()"></a>', strtolower($functionname));
		$html.= sprintf('<dl><pre><dt><code>%s%s%s %s <b>%s</b>( %s );</code>%s%s</dt></pre><dd>%s%s</dd>', 
											$abstract,
											$static,
											$data["access"],
											$data["return"]["type"],
											$functionname,
											$param_overview,
											$this->CR_HTML,
											$this->checkBaseclass($data, $functionname),
											$this->CR_HTML, 
											$data["undocumented"] ? "Undocumented." : $data["desc"]
										);
		
		if (0!=count($data["param"])) {
		
			$html.= "<p><dl><dt>Parameters";
			$html.= $this->checkInheritedFieldFrom($data, "param", $functionname);
			$html.= ":</dt><dd><p><dl>". $this->CR_HTML;
			
			reset($data["param"]);
			while (list($k, $params)=each($data["param"])) {
				$html.= sprintf('<dt><code>%s %s</code></dt><dd>%s</dd>%s', 	
													$params["type"],
													$params["name"],
													$params["desc"],
													$this->CR_HTML
											);
			}
			$html.= "</dl></dd></dl>".$this->CR_HTML;
		}

		if ("void"!=$data["return"]["type"] ) {
			$html.="<p><dl><dt>Returns";
			$html.= $this->checkInheritedFieldFrom($data, "return", $functionname);
			$html.=":</dt><dd><p><code>".$this->CR_HTML;
			
			$html.= sprintf('%s %s</code<br>%s%s</dd></dl>%s',
												$data["return"]["type"],
												$data["return"]["name"],
												$this->CR_HTML,
												$data["return"]["desc"],
												$this->CR_HTML
											);
		}
		
		if (0!=count($data["throws"])) {
			$html.= "<p><dl><dt>Throws";
			$html.= $this->checkInheritedFieldFrom($data, "throws", $functionname);
			$html.= ":</td><dd><p><dl><dt><code>".$this->CR_HTML;
			
			reset($data["throws"]);
			while (list($k, $exception)=each($data["throws"])) 
				$html.= $exception.", ";
			$html = substr($html, 0, -2).$this->CR_HTML;
			
			$html.="</code></dt></dl></dd></dl>".$this->CR_HTML;
		} 
		
		if (""!=$data["since"]) {
			$html.= "<p><dl><dt>Since";
			$html.= $this->checkInheritedFieldFrom($data, "since", $functionname);
			$html.=":</dt><dd>".$this->CR_HTML;
			$html.=	$data["since"]."</dd></dl>".$this->CR_HTML;
		}
		
		if (""!=$data["version"]) {
			$html.= "<p><dl><dt>Version";
			$html.= $this->checkInheritedFieldFrom($data, "version", $functionname);
			$html.= ":</dt><dd>".$this->CR_HTML;
			$html.= $data["version"]."</dd></dl>".$this->CR_HTML;
		}
		
		if (""!=$see) {
			$html.= "<p><dl><dt>See also";
			$html.= $this->checkInheritedFieldFrom($data, "see", $functionname);
			$html.= ":</dt><dd>".$this->CR_HTML;
			$html.= $see."</dd></dl>".$this->CR_HTML;
		}
		
		if (is_array($data["brother"])) {
			$html.= "<p><dl><dt>Brother:</dt><dd>";
			$html.= sprintf('<a href="%s.html#%s()">%s</a>',
												$data["brother"]["parentclass"],
												$data["brother"]["function"],
												$data["brother"]["function"]
											);
			$html.= "</dd></dl>".$this->CR_HTML;
		}
		
		if (""!=$data["author"]) {
			$html.= "<p><dl><dt>Author(s):</dt><dd>";
			$data["author"] = preg_replace("/<([^>]*)>/", '<a href="mailto:\1">&lt;\1&gt;</a>', $data["author"]);
			$html.= $data["author"]."</dd></dl>".$this->CR_HTML;
		}
		
		if (""!=$data["copyright"]) {
			$html.= "<p><dl><dt>Copyright:</dt><dd>";
			$data["copyright"] = preg_replace("/<([^>]*)>/", '<a href="mailto:\1">&lt;\1&gt;</a>', $data["copyright"]);
			$html.= $data["copyright"]."</dd></dl>".$this->CR_HTML;
		}

		$html.= "</dl><hr>".$this->CR_HTML;
		return $html;
	} // end func getFunctionDetail
	
	/**
	* Renders a summary of a function.
	* @param	string	$function
	* @param	string	$functionname
	* @return	array		$summary
	* @access	public
	*/
	function getFunctionSummary($functionname, $data) {
		if (""==$functionname || !is_array($data)) 
			return array("", "", "");

		if (!isset($data["return"]["type"]))
			echo $functionname."<hr>";
		$return 		= "<pre><code>".$data["return"]["type"]."</code></pre>";
		$overrides = $this->checkBaseclass($data, $functionname);
		
		return array($return, $overrides, $data["shortdesc"]);
	} // end func getFunctionSummary
	
	/**
	* Returns an HTML anchor to the parent function if available
	* @param	array		$data
	* @param	string	$functionname
	* @access	private
	* @return	string	$html
	*/
	function checkBaseclass($data, $functionname) {
		if (isset($data["baseclass"])) {
			$html = sprintf('[overrides: <a href="%s.html%s()">%s->%s()</a>]',
												$data["baseclass"],
												strtolower($functionname),
												$data["baseclass"],
												$functionname,
												$this->CR_HTML
											);
		} else {
			$html = "";
		}
		
		return $html;
	} // end func checkBaseclass
	
	/**
	* Returns an HTML anchor if the field is inherited from another class
	* @param	array		$data
	* @param	string 	$field
	* @param	string	$functionname
	* @return	string	$html
	* @access	private
	*/
	function checkInheritedFieldFrom($data, $field, $functionname) {
		if (isset($data["inherited"][$field])) {
			$html = sprintf(' [from: <a href="%s.html#%s()">%s->%s()</a>]',
														$data["inherited"][$field],
														strtolower($functionname),
														$data["inherited"][$field],
														$functionname
												);
		} else {
			$html = "";
		}
		
		return $html;
	} // end func checkInheritedFieldFrom
	
	/**
	* Renders the parameters of a function so that they can be 
	* used in the prototype.
	* @param	string	$function
	* @param	array		$params
	* @param	int			$length
	* @return	string	$param_overview
	* @access	private
	*/
	function getParamOverview($function, $params, $length=0) {
		if (""==$function) 
			return "";
		if (0==count($params))
			return "void";

		$param_overview = "";
		$length					= (0==$length) ? strlen($function)+2 : $length+2;
		$indent 				= $this->getIndent($length);

		reset($params);
		while (list($k, $data)=each($params)) 
			$param_overview.= sprintf("%-10s %s,%s%s", $data["type"],	$data["name"], $this->CR_HTML, $indent	);
		
		$param_overview = substr($param_overview, 0, -1*($length+strlen($this->CR_HTML)+1) );
		if (""==$param_overview)
			$param_overview = "void";
			
		return $param_overview;
	} // end func getParamOverview
	
} // end class PhpdocFunctionRenderer
?>