<?php
/**
* Renders Classtrees
* @author		Ulf Wendel <ulf@redsys.de>
* @version  0.1alpha
* @since		0.3alpha
*/
class PhpdocIndexClasstreeRenderer extends PhpdocIndexRendererObject {

	/**
	* Renders a classtree of all classes in a package
	* @param	enum		$mode		You can get "horizontal", "vertical" or "tree" styled classtrees
	* 												(default: horizontal)
	*	@return	string	$html
	* @access	public
	* @see		getClasstreeVertical(), getClasstreeTree(), getClasstreeHorizontal()
	*/
	function getClasstree($mode = "vertical") {
	
		$html = "";
		$this->outl("      ... rendering '$mode' classtree");
		
		reset($this->indexer_result["classTree"]["baseclasses"]);
		while (list($k, $baseclassdata)=each($this->indexer_result["classTree"]["baseclasses"])) {
			
			switch($mode) {
				case "vertical":
					$html.= $this->getClasstreeVertical($baseclassdata["classname"]);
					break;
				
				case "tree":
					$html.= $this->getClasstreeTree($baseclassdata["classname"]);
					break;
					
				case "horizontal":
				default:
					$html.= $this->getClasstreeHorizontal($baseclassdata["classname"]);
					break;
					
			}	
			
			$html.="<p><hr><p>";
			
		}
		
		return $html;
	} // end func getClasstree()

	/**
	* Renders a horizontal classtree
	* @param	string	$classname
	* @see		getClasstree(), getClasstreeVertical(), getClasstreeTree()
	*/	
	function getClasstreeHorizontal($classname) {
		
		if (isset($this->indexer_result["classTree"]["subclasslist"][$classname])) {

			$colspan = count($this->indexer_result["classTree"]["subclasslist"][$classname]);
			$html= sprintf('<table border>%s<tr><td align="center" valign="top" colspan="%d">%s</td></tr>%s',
												$this->CR_HTML,
												$colspan,
												$this->getClasstreeEntry($classname),
												$this->CR_HTML
											);

			reset($this->indexer_result["classTree"]["subclasslist"][$classname]);
			while (list($subclass, $ok)=each($this->indexer_result["classTree"]["subclasslist"][$classname])) 
				$html.= sprintf('<td align="center" valign="top">%s</td>%s', 
													$this->getClasstreeHorizontal($subclass),
													$this->CR_HTML
											);
			
			$html.="</tr>".$this->CR_HTML;
			$html.= "</table>".$this->CR_HTML;
											
		} else {
		
			$html = '<table border><tr><td align="center" valign="top">';
			$html.= $this->getClasstreeEntry($classname);
			$html.= '</td></tr></table>';
			
		}			
		
		return $html;
	} // end func getClasstreeHorizontal
	
	/**
	* Renders a vertical classtree
	* @param	string	$classname
	* @see		getClasstree(), getClasstreeHorizontal(), getClasstreeTree()
	*/	
	function getClasstreeVertical($classname) {
		
		if (isset($this->indexer_result["classTree"]["subclasslist"][$classname])) {

			$rowspan = count($this->indexer_result["classTree"]["subclasslist"][$classname]);
			$html= sprintf('<table border>%s<tr><td align="left" valign="middle" rowspan="%d">%s</td></tr>%s',
												$this->CR_HTML,
												$rowspan+1,
												$this->getClasstreeEntry($classname),
												$this->CR_HTML
											);

			
			
			reset($this->indexer_result["classTree"]["subclasslist"][$classname]);
			while (list($subclass, $ok)=each($this->indexer_result["classTree"]["subclasslist"][$classname])) 
				$html.= sprintf('<tr><td align="left" valign="middle">%s</td></tr>%s', 
													$this->getClasstreeVertical($subclass),
													$this->CR_HTML
											);
			
			$html.= '</table>';
			
		} else {
		
			$html = '<table border><tr><td align="left" valign="middle">';
			$html.= $this->getClasstreeEntry($classname);
			$html.= '</td></tr></table>';
			
		}			
		
		return $html;
	} // end func getClasstreeVertical
	
	/**
	* Renders a tree styled classtree
	* @param	string	$classname
	* @see		getClasstree(), getClasstreeHorizontal(), getClasstreeCErtical()
	*/	
	function getClasstreeTree($classname) {
		
		if (isset($this->indexer_result["classTree"]["subclasslist"][$classname])) {

			$html = sprintf('<table>%s<tr><td align="left" valign="middle" colspan="2">%s</td></tr>%s',
												$this->CR_HTML,
												$this->getClasstreeEntry($classname),
												$this->CR_HTML
											);

			$html.= '<tr><td align="left" valign="top"><font face="Arial, Helvetica" size="1">&nbsp;&nbsp;&nbsp;|';
			$html.= '</font></td></tr>'.$this->CR_HTML;
											
			reset($this->indexer_result["classTree"]["subclasslist"][$classname]);
			while (list($subclass, $ok)=each($this->indexer_result["classTree"]["subclasslist"][$classname])) {
			
				$html.= '<tr><td align="left" valign="top"><font face="Arial, Helvetica" size="1">&nbsp;&nbsp;&nbsp;+';
				$html.= '</font></td><td align="left" valign="top">';
				$html.= '<font face="Arial, Helvetica" size="1">';
				$html.= sprintf('[%s]</font><br>%s</td></tr>%s', 
													$classname,
													$this->getClasstreeTree($subclass),
													$this->CR_HTML
											);
			}										

			$html.= '</table>';
			
		} else {
			
			$html= $this->getClasstreeEntry($classname);
			
		}			
		
		return $html;
	} // end func getClasstreeTree
	
	/**
	* Renders one entry (classname) in any of the classtrees
	* @param	string	$classname
	* @return	string	$html
	*/
	function getClasstreeEntry($classname) {
		
		$html = sprintf('<b><a href="%s.html">%s</a></b><br>%s', 
												$classname, 
												$classname,
												$this->CR_HTML
										);
		
		$html.= sprintf('<font size="1" face="Arial, Helvetica"><br>%s',
											#$this->indexer_result["classTree"]["classinfo"][$classname]["filename"],
											$this->CR_HTML
									);
									
		$html.= sprintf('Version: %s, Since: %s<br>%s</font>',
											$this->indexer_result["classTree"]["classinfo"][$classname]["version"],
											$this->indexer_result["classTree"]["classinfo"][$classname]["since"],
											$this->CR_HTML
									);

		return $html;		
	} // end func getClasstreeEntry
	
} // end class PhpdocIndexClasstreeRenderer
?>